// JavaScript Document
function change_city(v)
{
  var prov=new Array();
  if(v==0) return false;
prov[10]="2754-S 上海";
prov[11]="1-H 合肥|1-H 黄山|1-J 九华山|1-W 芜湖|1-B 蚌埠|1-H 淮南|1-M 马鞍山|1-H 淮北|1-T 铜陵|1-A 安庆|1-C 滁州|1-F 阜阳|1-S 宿州|1-C 巢湖|1-Z 亳州|1-C 池州|1-X 宣城|1-L 六安|1-Z 砀山|1-S 寿县|1-H 霍山|1-Q 青阳|1-T 屯溪";
prov[12]="2423-A 澳门";
prov[13]="218-B 北京|223-C 昌平|224-C 朝阳|226-D 大兴|231-H 怀柔|236-S 顺义";
prov[14]="1-F 福州|1-W 武夷山|1-P 浦城|1-X 厦门|1-P 莆田|1-S 三明|1-Q 泉州|1-Z 漳州|1-N 南平|1-L 龙岩|1-N 宁德|1-S 邵武|1-Z 政和|1-F 福鼎|1-T 泰宁|1-C 长汀|1-S 上杭|1-Y 永安|1-Z 漳平|1-P 平潭|1-N 南安|1-C 崇武";
prov[15]="1-L 兰州|1-D 敦煌|1-B 白银|1-T 天水|1-J 酒泉|1-W 武威|1-Z 张掖|1-P 平凉|1-Q 庆阳|1-D 定西|1-L 陇南|1-G 甘南|1-L 临夏|1-A 安西|1-Y 玉门镇|1-J 金塔|1-S 山丹|1-Y 永昌|1-M 民勤|1-J 景泰|1-J 靖远|1-L 临洮|1-H 环县|1-X 西峰镇|1-M 玛曲|1-Z 岷县";
prov[16]="1-G 广州|1-S 汕头|1-S 深圳|1-Z 珠海|1-Z 湛江|1-H 惠阳|1-F 佛冈|1-N 南雄|1-M 梅县|1-D 电白|1-Y 阳江|1-S 韶关|1-N 南海|1-M 茂名|1-S 汕尾|1-H 河源|1-Q 清远|1-D 东莞|1-Z 中山|1-C 潮州|1-J 揭阳|1-Y 云浮|1-L 连县|1-L 连平|1-D 德庆|1-G 广宁|1-G 高要|1-W 五华|1-H 惠来|1-X 信宜|1-L 罗定|1-X 新会|1-T 台山|1-S 顺德|1-X 徐闻";
prov[17]="1-N 南宁|1-G 桂林|1-B 北海|1-L 柳州|1-F 防城港|1-Q 钦州|1-G 贵港|1-Y 玉林|1-B 百色|1-H 贺州|1-H 河池|1-L 来宾|1-C 崇左|1-W 梧州|1-R 融安|1-F 凤山|1-M 蒙山|1-N 那坡|1-J 靖西|1-P 平果|1-G 桂平|1-L 龙州|1-L 灵山|1-D 东兴|1-Z 涠洲岛";
prov[18]="1-G 贵阳|1-L 六盘水|1-Z 遵义|1-A 安顺|1-T 铜仁|1-B 毕节|1-Q 黔西|1-W 威宁|1-P 盘县|1-T 桐梓|1-C 赤水|1-S 思南|1-Z 镇宁|1-K 凯里|1-D 都匀|1-S 三穗|1-X 兴仁|1-W 望谟|1-X 兴义|1-L 罗甸|1-D 独山|1-Z 榕江";
prov[19]="1-H 海口|1-S 三亚|1-Q 琼海|1-Z 儋县|1-W 文昌|1-W 万宁|1-D 东方|1-C 澄迈|1-D 定安|1-T 屯昌|1-L 临高|1-B 白沙|1-L 乐东|1-L 陵水|1-B 保亭|1-Q 琼中|1-T 通什";
prov[20]="1-S 石家庄|1-C 承德|1-Q 秦皇岛|1-B 保定|1-T 唐山|1-H 邯郸|1-X 邢台|1-Z 张家口|1-C 沧州|1-L 廊坊|1-H 衡水|1-Z 张北|1-W 蔚县|1-F 丰宁|1-W 围场|1-H 怀来|1-Z 遵化|1-Q 青龙|1-B 坝县|1-L 乐亭|1-B 泊头|1-H 黄骅";
prov[21]="1-Z 郑州|1-L 洛阳|1-K 开封|1-P 平顶山|1-J 焦作|1-H 鹤壁|1-X 新乡|1-A 安阳|1-Z 濮阳|1-X 许昌|1-Z 漯河|1-S 三门峡|1-N 南阳|1-X 信阳|1-Z 周口|1-Z 驻马店|1-J 济源|1-S 商丘|1-L 卢氏|1-M 孟津|1-Z 栾川|1-X 西峡|1-B 宝丰|1-X 西华|1-G 固始";
prov[22]="1-H 哈尔滨|1-D 大兴安岭|1-H 黑河|1-Q 齐齐哈尔|1-H 鹤岗|1-S 双鸭山|1-S 绥芬河|1-J 鸡西|1-M 漠河|1-D 大庆|1-Y 伊春|1-M 牡丹江|1-J 佳木斯|1-B 勃利|1-S 绥化|1-T 塔河|1-X 新林|1-H 呼玛|1-N 嫩江|1-S 孙吴|1-B 北安|1-K 克山|1-F 富裕|1-H 海伦|1-M 明水|1-F 富锦|1-T 泰来|1-A 安达|1-T 铁力|1-Y 依兰|1-B 宝清|1-T 通河|1-S 尚志|1-H 虎林";
prov[23]="1-W 武汉|1-Y 宜昌|1-E 恩施|1-H 黄石|1-X 襄樊|1-J 荆门|1-E 鄂州|1-X 孝感|1-H 黄冈|1-X 咸宁|1-S 随州|1-X 仙桃|1-T 天门|1-Q 潜江|1-S 神农架|1-M 麻城|1-Z 枣阳|1-Y 郧西|1-Y 郧阳|1-F 房县|1-L 老河口|1-Z 钟祥|1-G 广水|1-W 五峰|1-J 荆州|1-L 来凤|1-J 嘉鱼|1-Y 英山";
prov[24]="1-C 长沙|1-Z 张家界|1-H 衡山|1-Y 益阳|1-S 桑植|1-Z 沅陵|1-Z 株洲|1-X 湘潭|1-H 衡阳|1-S 邵阳|1-Y 岳阳|1-C 常德|1-C 郴州|1-H 怀化|1-L 娄底|1-S 石门|1-J 吉首|1-A 安化|1-Z 沅江|1-P 平江|1-Z 芷江|1-S 韶山|1-S 双峰|1-T 通道|1-W 武冈|1-Y 永州|1-D 道县";
prov[25]="1-C 长春|1-C 长白|1-J 吉林|1-Y 延吉|1-L 辽源|1-T 通化|1-B 白山|1-Z 桦甸|1-J 集安|1-S 松原|1-B 白城|1-F 扶余|1-Q 前郭尔罗斯|1-T 通榆|1-C 长岭|1-S 双辽|1-S 四平|1-Y 永吉|1-D 敦化|1-W 汪清|1-D 东岗|1-S 松江|1-L 临江";
prov[26]="1-N 南京|1-S 苏州|1-W 无锡|1-Y 扬州|1-X 徐州|1-C 常州|1-N 南通|1-L 连云港|1-Z 盱眙|1-G 赣榆|1-D 东台|1-G 高邮|1-H 淮安|1-Y 盐城|1-Z 镇江|1-T 泰州|1-S 宿迁|1-H 淮阴|1-S 射阳|1-Z 溧阳|1-Y 宜兴|1-C 常熟|1-K 昆山|1-T 太仓";
prov[27]="1-N 南昌|1-L 庐山|1-J 景德镇|1-G 赣州|1-J 井冈山|1-Y 玉山|1-G 贵溪|1-G 广昌|1-P 萍乡|1-X 新余|1-J 九江|1-Y 鹰潭|1-Y 宜春|1-F 抚州|1-S 上饶|1-X 修水|1-J 吉安|1-N 宁冈|1-D 都昌|1-Z 鄱阳|1-Z 樟树|1-N 南城|1-X 寻乌";
prov[28]="1-S 沈阳|1-D 大连|1-D 丹东|1-A 鞍山|1-J 锦州|1-F 抚顺|1-B 本溪|1-W 瓦房店|1-H 葫芦岛|1-Y 营口|1-P 盘锦|1-F 阜新|1-L 辽阳|1-T 铁岭|1-C 朝阳|1-Z 彰武|1-Y 叶柏寿|1-H 黑山|1-Z 章党|1-H 桓仁|1-S 绥中|1-K 宽甸|1-L 旅顺";
prov[29]="1-H 呼和浩特|1-Y 牙克石|1-B 包头|1-W 乌海|1-C 赤峰|1-T 通辽|1-D 东胜|1-E 二连浩特|1-W 乌兰浩特|1-X 锡林浩特|1-L 临河|1-A 阿拉善左旗|1-A 阿拉善右旗|1-H 海拉尔|1-E 额尔古纳右旗|1-T 图里河|1-X 小二沟|1-X 新巴尔虎右旗|1-B 博克图|1-A 阿儿山|1-S 索轮|1-D 东乌珠穆沁旗|1-E 额济纳旗|1-G 拐子湖|1-B 巴音毛道|1-N 那仁宝力格|1-M 满都拉|1-A 阿巴嘎旗|1-S 苏尼特左旗|1-H 海力素|1-Z 朱日和|1-W 乌拉特中旗|1-D 达尔罕茂明安联合旗|1-S 四子王旗|1-H 化德|1-J 集宁|1-J 吉兰太|1-E 鄂托克旗|1-X 西乌珠穆沁旗|1-Z 扎鲁特旗|1-B 巴林左旗|1-L 林西|1-K 开鲁|1-D 多伦|1-W 翁牛特旗|1-B 宝国图|1-Q 清水河|1-H 河南|1-M 满洲里";

prov[30]="1-Y 银川|1-S 石嘴山|1-G 固原|1-W 吴忠|1-H 惠农|1-T 陶乐|1-Z 中卫|1-Z 中宁|1-Y 盐池|1-T 同心|1-X 西吉";
prov[31]="1-X 西宁|1-G 刚察|1-H 海东|1-H 黄南|1-G 果洛|1-Y 玉树|1-D 德令哈|1-M 茫崖|1-L 冷湖|1-Q 祁连|1-M 门源|1-G 格尔木|1-W 乌兰|1-D 都兰|1-H 海晏|1-Q 恰卜恰|1-G 贵德|1-M 民和|1-X 兴海|1-T 同德|1-Z 杂多|1-Q 曲麻莱|1-M 玛多|1-D 达日|1-J 久治|1-N 囊谦|1-B 班玛";

prov[32]="1-J 济南|1-Q 青岛|1-Y 烟台|1-W 威海|1-W 潍坊|1-Z 淄博|1-Z 枣庄|1-D 东营|1-J 济宁|1-T 泰安|1-R 日照|1-L 莱芜|1-D 德州|1-L 临沂|1-L 聊城|1-B 滨州|1-H 菏泽|1-L 陵县|1-H 惠民县|1-C 长岛|1-L 龙口|1-C 成山头|1-C 朝城|1-Z 淄川|1-Y 沂源|1-L 莱阳|1-H 海阳|1-D 定陶|1-Z 兖州|1-Q 曲阜";

prov[33]="1-T 太原|1-W 五台山|1-D 大同|1-Y 阳泉|1-C 长治|1-J 晋城|1-S 朔州|1-P 平遥|1-X 忻州|1-L 临汾|1-Y 右玉|1-H 河曲|1-X 兴县|1-Y 原平|1-L 离石|1-Y 榆次|1-Y 榆社|1-Z 隰县|1-J 介休|1-Y 运城|1-Y 阳城";
prov[34]="1-X 西安|1-Y 延安|1-T 铜川|1-B 宝鸡|1-H 汉中|1-W 渭南|1-Y 榆林|1-A 安康|1-S 商州|1-X 咸阳|1-W 吴旗|1-H 横山|1-S 绥德|1-C 长武|1-L 洛川|1-H 韩城|1-W 武功|1-L 略阳|1-F 佛坪|1-Z 镇安|1-S 石泉";
prov[35]="1-C 成都|1-E 峨眉山|1-J 九寨沟|1-M 绵阳|1-Z 自贡|1-P 攀枝花|1-D 德阳|1-G 广元|1-S 遂宁|1-L 乐山|1-N 南充|1-Y 宜宾|1-G 广安|1-D 达州|1-Y 雅安|1-B 巴中|1-Z 资阳|1-A 阿坝|1-G 甘孜|1-X 西昌|1-Z 泸州|1-S 石渠|1-R 若尔盖|1-D 德格|1-S 色达|1-D 道孚|1-M 马尔康|1-H 红原|1-X 小金|1-S 松潘|1-D 都江堰|1-P 平武|1-B 巴塘|1-X 新龙|1-L 理塘|1-K 康定|1-M 木里|1-J 九龙|1-Y 越西|1-L 雷波|1-Y 盐源|1-H 会理|1-W 万源|1-Z 阆中|1-N 内江县|1-Z 泸县|1-X 叙永|1-M 眉山";
prov[36]="3538-G 高雄|3541-T 台北";
prov[37]="3082-T 天津|3095-T 塘沽";
prov[38]="1-L 拉萨|1-L 林芝|1-N 那曲|1-C 昌都|1-Z 泽当|1-R 日喀则|1-A 阿里|1-S 狮泉河|1-B 班戈|1-A 安多|1-S 申扎|1-D 当雄|1-L 拉孜|1-N 尼木|1-N 聂拉木|1-D 定日|1-J 江孜|1-C 错那|1-L 隆子|1-P 帕里|1-S 索县|1-D 丁青|1-J 嘉黎|1-B 波密|1-C 察隅";
prov[39]="1140-X 香港|1146-J 九龙";
prov[40]="1-W 乌鲁木齐|1-Y 伊宁|1-T 吐鲁番|1-K 克拉玛依|1-Q 奇台|1-S 石河子|1-A 阿拉尔|1-H 哈密|1-H 和田|1-A 阿克苏|1-K 喀什|1-A 阿图什|1-C 昌吉|1-B 博乐|1-H 哈巴河|1-F 福海|1-A 阿勒泰|1-F 富蕴|1-T 塔城|1-H 和布克赛尔|1-Q 青河|1-A 阿拉山口|1-T 托里|1-W 温泉|1-J 精河|1-W 乌苏|1-C 蔡家湖|1-Z 昭苏|1-B 巴仑台|1-D 达板城|1-B 巴音布鲁克|1-Y 焉耆|1-B 拜城|1-L 轮台|1-K 库车|1-K 库尔勒|1-W 乌恰|1-A 阿合奇|1-B 巴楚|1-K 柯坪|1-T 铁干里克|1-R 若羌|1-S 莎车|1-P 皮山|1-M 民丰|1-Q 且末|1-Y 于田|1-B 巴里坤|1-Y 伊吾";
prov[41]="1-K 昆明|1-D 大理|1-D 迪庆|1-L 丽江|1-X 西双版纳|1-D 德钦|1-R 瑞丽|1-Y 玉溪|1-B 保山|1-Z 昭通|1-S 思茅|1-L 临沧|1-H 红河|1-C 楚雄|1-D 德宏|1-G 贡山|1-W 维西|1-N 怒江州|1-H 华坪|1-H 会泽|1-T 腾冲|1-Y 元谋|1-Z 沾益|1-J 景东|1-Z 泸西|1-G 耿马|1-L 澜沧|1-Y 元江|1-Z 勐腊|1-J 江城|1-M 蒙自|1-P 屏边|1-G 广南";
prov[42]="1-H 杭州|1-N 宁波|1-L 乐清|1-W 温州|1-J 嘉兴|1-H 湖州|1-S 绍兴|1-Z 嵊州|1-P 平湖|1-Z 衢州|1-D 洞头|1-J 金华|1-T 台州|1-L 丽水|1-T 桐乡|1-Z 嵊泗|1-D 定海|1-L 龙泉|1-H 洪家|1-Y 玉环";
prov[43]="1-Z 重庆|1-F 奉节|1-F 涪陵|1-L 梁平|1-W 万县市|1-Q 黔江|1-Y 酉阳";
  
  var list=prov[v].split('|')
	city=document.custom.city
	city.options.length=1
	for(i in list) {
		var pname=list[i].split('-')
		city.options[i]=new Option(pname[1],pname[0]);
		//document.custom.city.options[i].text=pname[1];
	}
	//if(GetCookie('cityname'))city.value = GetCookie('cityname');
	city.options[0].selected=true;
}
function addc(id,n) {
	DelCookie('cityid');
	SetCookie('cityid',id,5184000,'/',top_domain());
	if(n.indexOf(" ")>0)n =n.split(" ")[1];
	SetCookie('cityname',n,5184000,'/');
	if(getObj("defaultcity")) getObj("defaultcity").innerHTML = n;
	//alert("您选择的城市已经定制成功!\n下次访问,该城市天气即在首页显示.");
}

function show_city() {
	var cityname=GetCookie('cityname');
	if(cityname) {
		document.write(cityname)
	}
}

function clearset()

{
  DelCookie('cityid');
  DelCookie('cityname');
  SetCookie('cityid',"",5184000,'/',top_domain());
  SetCookie('cityname',"",5184000,'/');
  //alert("操作成功");
}

function addc2()
{
  var new_city_id="";var fdc=false;
  if(custom.vCity.value=='')  {alert("请输入城市名称");custom.vCity.focus();return false;}
  for(i=0;i<citys.length;i++)
	{
			if (citys[i][1]==custom.vCity.value)
			{
				 new_city_id = citys[i][0];
	             SetCookie('cityid',new_city_id,5184000,'/',top_domain());
	             SetCookie('cityname',custom.vCity.value,5184000,'/');
	             if(getObj("defaultcity")) getObj("defaultcity").innerHTML = custom.vCity.value;
	             //alert("您输入的城市已经定制成功!\n下次访问,该城市天气即在首页显示.");
	             reloadWeather();
				 fdc=true;
				 break;
			}
     }      
  if(fdc==false) alert("你输入的城市不存在,请重新输入");else closeDiv('add_tianqi');
  
  
	
}